import json
import sys

from . import compile_to_code


def main():
    if len(sys.argv) == 2:
        definition = sys.argv[1]
    else:
        definition = sys.stdin.read()

    definition = json.loads(definition)
    code = compile_to_code(definition)
    print(code)


if __name__ == '__main__':
    main()



import pytest

from fastjsonschema import JsonSchemaValueException


@pytest.mark.parametrize('value, testError', (
    ('foo', False),
    (42, False),
    (False, False),
    ([1, 2, 3], False),
    ('\'"', False),
    ('foo', True),
    ('\'"', False),
))
def test_const(asserter, value, testError):
    const = expected = value
    if testError:
        const = 'x'
        expected = JsonSchemaValueException('data must be same as const definition: x', value='{data}', name='data', definition='{definition}', rule='const')
    
    asserter({
        '$schema': 'http://json-schema.org/draft-06/schema',
        'const': const,
    }, value, expected)



import pytest

from fastjsonschema import JsonSchemaValueException


BASE_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema',
    "if": {
        "const": 1
    },
}


@pytest.mark.parametrize('value, expected', [
    (1, 1),
    (2, 2),
])
def test_boolean_schema_true_in_then(asserter, value, expected):
    asserter({
        **BASE_SCHEMA,
        'then': True,
        'else': {
            'type': 'number'
        },
    }, value, expected)


@pytest.mark.parametrize('value, expected', [
    (1, JsonSchemaValueException(
        'data must not be there', value=1, name='data',
        definition=False, rule=None
    )),
    (2, 2),
])
def test_boolean_schema_false_in_then(asserter, value, expected):
    asserter({
        **BASE_SCHEMA,
        'then': False,
        'else': {
            'type': 'number'
        },
    }, value, expected)


@pytest.mark.parametrize('value, expected', [
    (1, 1),
    (2, 2),
])
def test_boolean_schema_true_in_else(asserter, value, expected):
    asserter({
        **BASE_SCHEMA,
        'then': {
            'type': 'number',
        },
        'else': True,
    }, value, expected)


@pytest.mark.parametrize('value, expected', [
    (1, 1),
    (2, JsonSchemaValueException(
        'data must not be there', value=2, name='data',
        definition=False, rule=None
    )),
])
def test_boolean_schema_false_in_else(asserter, value, expected):
    asserter({
        **BASE_SCHEMA,
        'then': {
            'type': 'number',
        },
        'else': False,
    }, value, expected)
